@@ -2,16 +2,10 @@
 # vim: set expandtab shiftwidth=4:
 
 """
-.. module:: manager
-   :synopsis: Python Interface for Asterisk Manager
+Python Interface for Asterisk Manager
 
 This module provides a Python API for interfacing with the asterisk manager.
 
-Example
--------
-
-.. code-block:: python
-
    import asterisk.manager
    import sys
 
@@ -38,14 +32,14 @@ Example
            response = manager.status()
 
            manager.logoff()
-       except asterisk.manager.ManagerSocketException as e:
-          print "Error connecting to the manager: %s" % e.strerror
+       except asterisk.manager.ManagerSocketException, (errno, reason):
+          print "Error connecting to the manager: %s" % reason
           sys.exit(1)
-       except asterisk.manager.ManagerAuthException as e:
-          print "Error logging in to the manager: %s" % e.strerror
+       except asterisk.manager.ManagerAuthException, reason:
+          print "Error logging in to the manager: %s" % reason
           sys.exit(1)
-       except asterisk.manager.ManagerException as e:
-          print "Error: %s" % e.strerror
+       except asterisk.manager.ManagerException, reason:
+          print "Error: %s" % reason
           sys.exit(1)
 
    finally:
@@ -56,22 +50,14 @@ Remember all header, response, and event names are case sensitive.
 
 Not all manager actions are implmented as of yet, feel free to add them
 and submit patches.
-
-Specification
--------------
 """
 
-import sys
-import os
 import socket
 import threading
-from six import PY3
-from six.moves import queue
-import re
+import queue
 from types import *
-from time import sleep
 
-EOL = '\r\n'
+EOL = '\n'
 
 
 class ManagerMsg(object):
@@ -117,15 +103,7 @@ class ManagerMsg(object):
                 break
             try:
                 k, v = (x.strip() for x in line.split(':', 1))
-                # if header is ChanVariable it can have more that one value
-                # we store the variable in a dictionary parsed
-                if 'ChanVariable' in k:
-                    if not self.headers.has_key('ChanVariable'):
-                        self.headers['ChanVariable']={}
-                    name, value = (x.strip() for x in v.split('=',1))
-                    self.headers['ChanVariable'][name]=value
-                else:
-                    self.headers[k] = v
+                self.headers[k] = v
             except ValueError:
                 # invalid header, start of multi-line data response
                 data.extend(response[n:])
@@ -280,7 +258,7 @@ class Manager(object):
 
         # lock the socket and send our command
         try:
-            self._sock.write(command.encode('utf8','ignore'))
+            self._sock.write(command)
             self._sock.flush()
         except socket.error as e:
             raise ManagerSocketException(e.errno, e.strerror)
@@ -302,13 +280,11 @@ class Manager(object):
         multiline = False
         status = False
         wait_for_marker = False
-        eolcount = 0
         # loop while we are sill running and connected
         while self._running.isSet() and self._connected.isSet():
             try:
                 lines = []
                 for line in self._sock:
-                    line = line.decode('utf8','ignore')
                     # check to see if this is the greeting line
                     if not self.title and '/' in line and not ':' in line:
                         # store the title of the manager we are connecting to:
@@ -340,7 +316,7 @@ class Manager(object):
 
                     # line not ending in \r\n or without ':' isn't a
                     # valid header and starts multiline response
-                    if not line.endswith('\r\n') or ':' not in line:
+                    if not line.endswith(EOL) or ':' not in line:
                         multiline = True
                     # Response: Follows indicates we should wait for end
                     # marker --END COMMAND--
@@ -348,7 +324,7 @@ class Manager(object):
                             line.split(':', 1)[1].strip() == 'Follows':
                         wait_for_marker = True
                     # same when seeing end of multiline response
-                    if multiline and (line.startswith('--END COMMAND--') or line.strip().endswith('--END COMMAND--')):
+                    if multiline and line.startswith('--END COMMAND--'):
                         wait_for_marker = False
                         multiline = False
                     # same when seeing end of status response
@@ -428,7 +404,7 @@ class Manager(object):
                 elif message.has_header('Response'):
                     self._response_queue.put(message)
                 else:
-                    print('No clue what we got\n%s' % message.data)
+                    print('No clue what we got\n{}'.format(message.data))
         finally:
             # wait for our data receiving thread to exit
             t.join()
@@ -462,19 +438,11 @@ class Manager(object):
         if self._connected.isSet():
             raise ManagerException('Already connected to manager')
 
-        # make sure host is a string
-        assert type(host) is str
-
-        port = int(port)  # make sure port is an int
-
         # create our socket and connect
         try:
             _sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
-            _sock.connect((host, port))
-            if PY3:
-                self._sock = _sock.makefile(mode='rwb', buffering=0)
-            else:
-                self._sock = _sock.makefile()
+            _sock.connect((host, int(port)))
+            self._sock = _sock.makefile('rw')
             _sock.close()
         except socket.error as e:
             raise ManagerSocketException(e.errno, e.strerror)
@@ -531,25 +499,20 @@ class Manager(object):
     def ping(self):
         """Send a ping action to the manager"""
         cdict = {'Action': 'Ping'}
-        response = self.send_action(cdict)
-        return response
+        return self.send_action(cdict)
 
     def logoff(self):
         """Logoff from the manager"""
 
         cdict = {'Action': 'Logoff'}
-        response = self.send_action(cdict)
-
-        return response
+        return self.send_action(cdict)
 
     def hangup(self, channel):
         """Hangup the specified channel"""
 
         cdict = {'Action': 'Hangup'}
         cdict['Channel'] = channel
-        response = self.send_action(cdict)
-
-        return response
+        return self.send_action(cdict)
 
     def status(self, channel=''):
         """Get a status message from asterisk"""
@@ -575,7 +538,7 @@ class Manager(object):
 
         return response
 
-    def originate(self, channel, exten, context='', priority='', timeout='', application='', data='', caller_id='', run_async=False, earlymedia='false', account='', variables={}):
+    def originate(self, channel, exten, context='', priority='', timeout='', caller_id='', async=False, account='', variables={}):
         """Originate a call"""
 
         cdict = {'Action': 'Originate'}
@@ -587,16 +550,10 @@ class Manager(object):
             cdict['Priority'] = priority
         if timeout:
             cdict['Timeout'] = timeout
-        if application:
-            cdict['Application'] = application
-        if data:
-            cdict['Data'] = data
         if caller_id:
             cdict['CallerID'] = caller_id
-        if run_async:
+        if async:
             cdict['Async'] = 'yes'
-        if earlymedia:
-            cdict['EarlyMedia'] = earlymedia
         if account:
             cdict['Account'] = account
         # join dict of vairables together in a string in the form of 'key=val|key=val'
@@ -674,52 +631,6 @@ class Manager(object):
         response = self.send_action(cdict)
         return response
 
-    def sipshowregistry(self):
-        cdict = {'Action': 'SIPShowregistry'}
-        response = self.send_action(cdict)
-        return response
-
-    def iaxregistry(self):
-        cdict = {'Action': 'IAXregistry'}
-        response = self.send_action(cdict)
-        return response
-
-    def reload(self, module):
-        """ Reloads config for a given module """
-
-        cdict = {'Action': 'Reload'}
-        cdict['Module'] = module
-        response = self.send_action(cdict)
-        return response
-
-    def dbdel(self, family, key):
-        cdict = {'Action': 'DBDel'}
-        cdict['Family'] = family
-        cdict['Key'] = key
-        response = self.send_action(cdict)
-        return response
-
-    def dbdeltree(self, family, key):
-        cdict = {'Action': 'DBDelTree'}
-        cdict['Family'] = family
-        cdict['Key'] = key
-        response = self.send_action(cdict)
-        return response
-
-    def dbget(self, family, key):
-        cdict = {'Action': 'DBGet'}
-        cdict['Family'] = family
-        cdict['Key'] = key
-        response = self.send_action(cdict)
-        return response
-
-    def dbput(self, family, key, val):
-        cdict = {'Action': 'DBPut'}
-        cdict['Family'] = family
-        cdict['Key'] = key
-        cdict['Val'] = val
-        response = self.send_action(cdict)
-        return response
 
 class ManagerException(Exception):
     pass
